@@ -18,7 +18,31 @@ Readonly::Scalar my $LAST_INDEX => -1;
 Readonly::Scalar my $SPACE => q{ };
 
 # Version.
-our $VERSION = 0.05;
+our $VERSION = 0.06;
+
+# Finalize Tags output.
+sub finalize {
+	my $self = shift;
+
+	# XML mode.
+	if ($self->{'xml'}) {
+
+		# Add ending of all opened tags.
+		while (@{$self->{'printed_tags'}}) {
+			$self->put(['e', $self->{'printed_tags'}->[0]]);
+		}
+
+	# SGML mode.
+	} else {
+
+		# Flush tmp code.
+		if (scalar @{$self->{'tmp_code'}}) {
+			$self->_flush_tmp('>');
+		}
+		$self->{'printed_tags'} = [];
+	}
+	return;
+}
 
 # Resets internal variables.
 sub reset {
@@ -268,8 +292,8 @@ sub _put_data {
 # End of tag.
 sub _put_end_of_tag {
 	my ($self, $tag) = @_;
-	my $printed = shift @{$self->{'printed_tags'}};
 	if ($self->{'xml'}) {
+		my $printed = shift @{$self->{'printed_tags'}};
 		if (! defined $printed) {
 			err "Ending bad tag: '$tag' doesn't begin.";
 		} elsif ($printed ne $tag) {
@@ -648,6 +672,6 @@ L<http://skim.cz/>
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
